package com.ruoyi.ss.clean.mapper;

import java.util.List;

import com.ruoyi.ss.clean.domain.Clean;
import com.ruoyi.ss.clean.domain.CleanQuery;
import com.ruoyi.ss.clean.domain.CleanVO;
import org.apache.ibatis.annotations.Param;

/**
 * 保洁记录Mapper接口
 *
 * @author qzz
 * @date 2024-11-19
 */
public interface CleanMapper
{
    /**
     * 查询保洁记录
     *
     * @param cleanId 保洁记录主键
     * @return 保洁记录
     */
    public CleanVO selectECleanByCleanId(Long cleanId);

    /**
     * 查询保洁记录列表
     *
     * @param query 保洁记录
     * @return 保洁记录集合
     */
    public List<CleanVO> selectECleanList(@Param("query") CleanQuery query);

    /**
     * 新增保洁记录
     *
     * @param eClean 保洁记录
     * @return 结果
     */
    public int insertEClean(Clean eClean);

    /**
     * 修改保洁记录
     *
     * @param eClean 保洁记录
     * @return 结果
     */
    public int updateEClean(@Param("data") Clean eClean);

    /**
     * 删除保洁记录
     *
     * @param cleanId 保洁记录主键
     * @return 结果
     */
    public int deleteECleanByCleanId(Long cleanId);

    /**
     * 批量删除保洁记录
     *
     * @param cleanIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteECleanByCleanIds(Long[] cleanIds);
}
